@@ -3,9 +3,9 @@
 """Tests pageBreakBefore, frameBreakBefore, keepWithNext...
 """
 __version__='3.3.0'
-from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation
+from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation, invariantSeed
 setOutDir(__name__)
-import sys, os, time, re, random
+import sys, os, time, re
 from reportlab.rl_config import invariant as rl_invariant
 from operator import truth
 import unittest
@@ -14,12 +14,11 @@ from reportlab.lib import colors
 from reportlab.lib.units import cm, mm
 from reportlab.lib.enums import TA_LEFT, TA_RIGHT, TA_CENTER, TA_JUSTIFY
 from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
-from reportlab.platypus import ShowBoundaryValue
 from reportlab.platypus.frames import Frame
 from reportlab.lib.randomtext import randomText, PYTHON
 from reportlab.platypus.doctemplate import PageTemplate, BaseDocTemplate, Indenter, SimpleDocTemplate, LayoutError
 from reportlab.platypus.paragraph import *
-from reportlab.pdfgen.canvas import Canvas
+from reportlab.pdfgen.canvas import Canvas, ShowBoundaryValue
 from reportlab.rl_config import paraFontSizeHeightOffset
 from reportlab.pdfbase.pdfmetrics import stringWidth
 from reportlab.lib.pagesizes import A4, portrait
@@ -64,7 +63,7 @@ virtual gibberish (e.g. (98d)).
 def _test0(self):
     "This makes one long multi-page paragraph in test_platypus_breaking."
 
-    if rl_invariant: random.seed(1532760416)
+    invariantSeed(1532760416)
     def RT(k,theme='PYTHON',sentences=1,cache={}):
         if k not in cache:
             cache[k] = randomText(theme=theme,sentences=sentences)
